## Zoy

Utility to count lines of python code, scripts, directories, etc. in projects.

<img src=https://github.com/tomlin7/zoy/assets/70792552/1ed5fff1-0c0e-453c-86a0-1da2ea10456f width=500>

### Installation

```bash
$ pip install zoy
```